==========================
Frequently Asked Questions
==========================

Does MongoEngine support asynchronous drivers (Motor, TxMongo)?
---------------------------------------------------------------

No, MongoEngine is exclusively based on PyMongo and isn't designed to support other driver.
If this is a requirement for your project, check the alternative:  `uMongo`_ and `MotorEngine`_.

.. _uMongo: https://umongo.readthedocs.io/
.. _MotorEngine: https://motorengine.readthedocs.io/
